@@ -13,10 +13,10 @@ from ..tasks import (
     AzureDataLakeCopy,
     AzureDataLakeToDF,
     AzureSQLCreateTable,
-    BCPTask,
-    DownloadGitHubFile,
     AzureSQLDBQuery,
+    BCPTask,
     CheckColumnOrder,
+    DownloadGitHubFile,
 )
 
 logger = logging.get_logger(__name__)
@@ -105,6 +105,7 @@ class ADLSToAzureSQL(Flow):
         if_exists: Literal["fail", "replace", "append", "delete"] = "replace",
         check_col_order: bool = True,
         sqldb_credentials_secret: str = None,
+        on_bcp_error: Literal["skip", "fail"] = "skip",
         max_download_retries: int = 5,
         tags: List[str] = ["promotion"],
         vault_name: str = None,
@@ -115,7 +116,6 @@ class ADLSToAzureSQL(Flow):
         Flow for downloading data from different marketing APIs to a local CSV
         using Supermetrics API, then uploading it to Azure Data Lake,
         and finally inserting into Azure SQL Database.
-
         Args:
             name (str): The name of the flow.
             local_file_path (str, optional): Local destination path. Defaults to None.
@@ -137,10 +137,12 @@ class ADLSToAzureSQL(Flow):
             check_col_order (bool, optional): Whether to check column order. Defaults to True.
             sqldb_credentials_secret (str, optional): The name of the Azure Key Vault secret containing a dictionary with
             Azure SQL Database credentials. Defaults to None.
+            on_bcp_error (Literal["skip", "fail"], optional): What to do if error occurs. Defaults to "skip".
             max_download_retries (int, optional): How many times to retry the download. Defaults to 5.
             tags (List[str], optional): Flow tags to use, eg. to control flow concurrency. Defaults to ["promotion"].
             vault_name (str, optional): The name of the vault from which to obtain the secrets. Defaults to None.
         """
+
         adls_path = adls_path.strip("/")
         # Read parquet
         if adls_path.split(".")[-1] in ["csv", "parquet"]:
@@ -174,13 +176,14 @@ class ADLSToAzureSQL(Flow):
         # AzureSQLCreateTable
         self.table = table
         self.schema = schema
-        self.if_exists = self._map_if_exists(if_exists)
+        self.if_exists = if_exists
         self.check_col_order = check_col_order
         # Generate CSV
         self.remove_tab = remove_tab
 
         # BCPTask
         self.sqldb_credentials_secret = sqldb_credentials_secret
+        self.on_bcp_error = on_bcp_error
 
         # Global
         self.max_download_retries = max_download_retries
@@ -278,7 +281,7 @@ class ADLSToAzureSQL(Flow):
             schema=self.schema,
             table=self.table,
             dtypes=dtypes,
-            if_exists=self.if_exists,
+            if_exists=self._map_if_exists(self.if_exists),
             credentials_secret=self.sqldb_credentials_secret,
             vault_name=self.vault_name,
             flow=self,
@@ -287,6 +290,8 @@ class ADLSToAzureSQL(Flow):
             path=self.local_file_path,
             schema=self.schema,
             table=self.table,
+            error_log_file_path=self.name.replace(" ", "_") + ".log",
+            on_error=self.on_bcp_error,
             credentials_secret=self.sqldb_credentials_secret,
             vault_name=self.vault_name,
             flow=self,
@@ -295,7 +300,6 @@ class ADLSToAzureSQL(Flow):
         df_reorder.set_upstream(lake_to_df_task, flow=self)
         df_to_csv.set_upstream(df_reorder, flow=self)
         promote_to_conformed_task.set_upstream(df_to_csv, flow=self)
-        promote_to_conformed_task.set_upstream(df_to_csv, flow=self)
         create_table_task.set_upstream(df_to_csv, flow=self)
         promote_to_operations_task.set_upstream(promote_to_conformed_task, flow=self)
         bulk_insert_task.set_upstream(create_table_task, flow=self)
