@@ -4,6 +4,7 @@ from datetime import timedelta
 from typing import List
 
 import pandas as pd
+import numpy as np
 from prefect import Task
 from prefect.tasks.secrets import PrefectSecret
 from prefect.utilities.tasks import defaults_from_attrs
@@ -519,6 +520,8 @@ class AzureDataLakeList(Task):
     def run(
         self,
         path: str = None,
+        recursive: bool = False,
+        file_to_match: str = None,
         gen: int = None,
         sp_credentials_secret: str = None,
         vault_name: str = None,
@@ -528,7 +531,9 @@ class AzureDataLakeList(Task):
         """Task run method.
 
         Args:
-            from_path (str): The path to the directory which contents you want to list. Defaults to None.
+            path (str, optional): The path to the directory which contents you want to list. Defaults to None.
+            recursive (bool, optional): If True, recursively list all subdirectories and files. Defaults to False.
+            file_to_match (str, optional): If exist it only returns files with that name. Defaults to None.
             gen (int): The generation of the Azure Data Lake. Defaults to None.
             sp_credentials_secret (str, optional): The name of the Azure Key Vault secret containing a dictionary with
             ACCOUNT_NAME and Service Principal credentials (TENANT_ID, CLIENT_ID, CLIENT_SECRET). Defaults to None.
@@ -567,10 +572,24 @@ class AzureDataLakeList(Task):
 
         full_dl_path = os.path.join(credentials["ACCOUNT_NAME"], path)
 
-        self.logger.info(f"Listing files in {full_dl_path}...")
-        files = lake.ls(path)
-        self.logger.info(f"Successfully listed files in {full_dl_path}.")
+        self.logger.info(f"Listing files in {full_dl_path}.")
+        if recursive:
+            self.logger.info("Loading ADLS directories recursively.")
+            files = lake.find(path)
+            if file_to_match:
+                conditions = [file_to_match in item for item in files]
+                valid_files = np.array([])
+                if any(conditions):
+                    index = np.where(conditions)[0]
+                    files = list(np.append(valid_files, [files[i] for i in index]))
+                else:
+                    raise FileExistsError(
+                        f"There are not any available file named {file_to_match}."
+                    )
+        else:
+            files = lake.ls(path)
 
+        self.logger.info(f"Successfully listed files in {full_dl_path}.")
         return files
 
 
@@ -632,7 +651,7 @@ class AzureDataLakeRemove(Task):
         """Task run method.
 
         Args:
-            path (str): The path to the directory contents of which you want to delete. Defaults to None.
+            path (str): The path to the directory or file you want to delete. Defaults to None.
             recursive (bool): Set this to True if removing files recursively. Defaults to False.
             gen (int): The generation of the Azure Data Lake. Defaults to None.
             sp_credentials_secret (str, optional): The name of the Azure Key Vault secret containing a dictionary with
@@ -663,8 +682,13 @@ class AzureDataLakeRemove(Task):
                 "AZURE_CLIENT_SECRET": os.environ["AZURE_CLIENT_SECRET"],
             }
         lake = AzureDataLake(gen=gen, credentials=credentials)
-
         full_path = os.path.join(credentials["ACCOUNT_NAME"], path)
-        self.logger.info(f"Deleting files from {full_path}...")
+
+        if full_path.endswith(".csv") or full_path.endswith(".parquet"):
+            logger_details = "file from"
+        else:
+            logger_details = "directory"
+
+        self.logger.info(f"Deleting {logger_details} {full_path}...")
         lake.rm(path, recursive=recursive)
-        self.logger.info(f"Successfully deleted files from {full_path}.")
+        self.logger.info(f"Successfully deleted {logger_details} {full_path}.")
