@@ -118,6 +118,8 @@ class SQLServerToDF(Task):
             config_key (str, optional): The key inside local config containing the credentials. Defaults to None.
 
         """
+        if config_key is None:
+            config_key = "SQL_SERVER"
         sql_server = SQLServer(config_key=config_key)
         df = sql_server.to_df(query=query)
         nrows = df.shape[0]
@@ -127,3 +129,43 @@ class SQLServerToDF(Task):
             f"Successfully downloaded {nrows} rows and {ncols} columns of data to a DataFrame."
         )
         return df
+
+
+class SQLServerQuery(Task):
+    def __init__(
+        self,
+        config_key: str = None,
+        *args,
+        **kwargs,
+    ):
+        """
+        Task for running queries on SQL Server.
+
+        Args:
+            config_key (str, optional): The key inside local config containing the credentials. Defaults to None.
+        """
+        self.config_key = config_key
+
+        super().__init__(name="sql_server_query", *args, **kwargs)
+
+    @defaults_from_attrs("config_key")
+    def run(
+        self,
+        query: str,
+        config_key: str = None,
+    ):
+        """
+        Ran query on SQL Server.
+
+        Args:
+            query (str, required): The query to execute on the SQL Server database.
+            config_key (str, optional): The key inside local config containing the credentials. Defaults to None.
+
+        """
+        if config_key is None:
+            config_key = "SQL_SERVER"
+        sql_server = SQLServer(config_key=config_key)
+        result = sql_server.run(query)
+
+        self.logger.info(f"Successfully ran the query.")
+        return result
